---
layout: page
title: Functional programming in Python
permalink: /about_function/
nav_order: 101
---

<h1 style="font-weight: bold">About functional programming in Python</h1>

While Python is technically a multi-paradigm language, its dynamic and weak typing system forbids it to apply a strictly functional approach. Moreover it seems a much more common development habits to make a wide use of the imperative, quick time-to-market imperative style. With this in mind, XFP tries to complete the functional programming experience while smoothly integrating with Python and capitalizing on its natural syntax.  


